summaryrefslogtreecommitdiffstats
path: root/src/libs/engine/OSCClient.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2006-06-20 21:56:12 +0000
committerDavid Robillard <d@drobilla.net>2006-06-20 21:56:12 +0000
commit032d526710d174b30e0c9f33ff9f7e60e99fb172 (patch)
tree21eefe5891ccf7f3bb7bd618c125afd928fc81c5 /src/libs/engine/OSCClient.cpp
parent34d46336eeccb2430df4d1ef00097890c400ab05 (diff)
downloadingen-032d526710d174b30e0c9f33ff9f7e60e99fb172.tar.gz
ingen-032d526710d174b30e0c9f33ff9f7e60e99fb172.tar.bz2
ingen-032d526710d174b30e0c9f33ff9f7e60e99fb172.zip
Renamed OmObject GraphObject;
Merged Port::prepare_buffers and Node::run into GraphObject::process. git-svn-id: http://svn.drobilla.net/lad/grauph@69 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/libs/engine/OSCClient.cpp')
-rw-r--r--src/libs/engine/OSCClient.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libs/engine/OSCClient.cpp b/src/libs/engine/OSCClient.cpp
index ff7c379f..7b92476b 100644
--- a/src/libs/engine/OSCClient.cpp
+++ b/src/libs/engine/OSCClient.cpp
@@ -468,13 +468,13 @@ OSCClient::object_renamed(const string& old_path, const string& new_path)
}
/** Sends all OmObjects known to the engine.
*/
/*
void
OSCClient::all_objects()
{
- for (Tree<OmObject*>::iterator i = om->object_store()->objects().begin();
+ for (Tree<GraphObject*>::iterator i = om->object_store()->objects().begin();
i != om->object_store()->objects().end(); ++i)
if ((*i)->as_node() != NULL && (*i)->parent() == NULL)
(*i)->as_node()->send_creation_messages(this);
@@ -468,13 +468,13 @@ OSCClient::object_renamed(const string& old_path, const string& new_path)
}
-/** Sends all OmObjects known to the engine.
+/** Sends all GraphObjects known to the engine.
*/
/*